#
# spec file for package python-azure-core
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%if 0%{?suse_version} >= 1500
%define skip_python2 1
%endif
Name:           python-azure-core
Version:        1.23.1
Release:        150200.6.3.2
Summary:        Microsoft Azure Core Library for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure-core/azure-core-%{version}.zip
Source1:        LICENSE.txt
Patch:          ac_lower-typing-extensions-version.patch
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.6}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-azure-nspkg >= 3.0.0
Requires:       python-requests >= 2.18.4
Requires:       python-six >= 1.11.0
Requires:       python-typing_extensions >= 3.10.0.0
Conflicts:      python-azure-sdk <= 2.0.0

BuildArch:      noarch

%python_subpackages

%description
The Azure Core pipeline is a re-structuring of the msrest pipeline introduced in msrest 0.6.0.
Further discussions on the msrest implementation can be found in the msrest wiki.

The Azure Core Pipeline is an implementation of chained policies as described in the
Azure SDK guidelines.

The Python implementation of the pipeline has some mechanisms specific to Python.
This is due to the fact that both synchronous and asynchronous implementations of the
pipeline must be supported independently.

%prep
%setup -q -n azure-core-%{version}
%patch -p1

%build
install -m 644 %{SOURCE1} %{_builddir}/azure-core-%{version}
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
}

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGELOG.md README.md
%license LICENSE.txt
%{python_sitelib}/azure/core
%{python_sitelib}/azure_core-*.egg-info

%changelog
* Tue Jul 25 2023 adrian.glaubitz@suse.com
- Update in SLE-15 (bsc#1199282, jsc#PM-3243, jsc#SLE-24629)
* Tue Jul 25 2023 adrian.glaubitz@suse.com
- Add patch to lower typing-extensions version requirement in setup.py
  + ac_lower-typing-extensions-version.patch
- Lower python-typing_extensions version to 3.10.0.0 in Requires
* Wed Apr 20 2022 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.23.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed Mar 30 2022 adrian.glaubitz@suse.com
- Update in SLE-15 (bsc#1189411, bsc#1191482)
* Fri Feb 11 2022 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.22.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Feb  4 2022 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.22.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Dec 13 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.21.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Dec  3 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.21.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Nov  9 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.20.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Nov  5 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.20.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Nov  2 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.19.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Oct  4 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.19.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Sep  7 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.18.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Aug  9 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.17.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Fri Jul  9 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.16.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Jun  8 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.15.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon May 10 2021 adrian.glaubitz@suse.com
- New upstream release (bsc#1185854)
  + Version 1.14.0b1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Remove temporary version override
* Tue May  4 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.13.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Temporarily override package version to 1.13.0.0 to allow
  upgrades from the previous 1.13.0b1 version
* Mon Mar 29 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.13.0b1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Feb 24 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.11.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Update Requires from setup.py
* Wed Jan 20 2021 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.10.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Dec 15 2020 adrian.glaubitz@suse.com
- Include in SLE-15 (bsc#1176785, jsc#ECO-3105, jsc#PM-2352)
* Thu Nov 26 2020 rjschwei@suse.com
- Only build Python3 flavors for distributions 15 and greater
* Thu Nov 12 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.9.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Mon Oct  5 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.8.1
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Tue Aug 25 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.8.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed May  6 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.5.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
* Wed Apr  1 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.3.0
  + For detailed information about changes see the
    CHANGELOG.md file provided with this package
- Rename HISTORY.md to CHANGELOG.md in %%files section
* Fri Jan 17 2020 adrian.glaubitz@suse.com
- New upstream release
  + Version 1.2.1
  + For detailed information about changes see the
    HISTORY.md file provided with this package
* Fri Oct  4 2019 adrian.glaubitz@suse.com
- Initial build
  + Version 1.0.0b3
